@@ -2,7 +2,7 @@
 from robster.model import LinearModel
 
 class SingleLayerPerceptron:
-  def __init__(self, epochs, mini_batch, MODEL = LinearModel, learning_rate = 0.001, report = 1):
+  def __init__(self, epochs, mini_batch, learning_rate = 0.001, report = 1, MODEL = LinearModel):
     self.epochs_ = epochs
     self.mini_batch_ = mini_batch
     self.learning_rate_ = learning_rate
